@@ -16,7 +16,6 @@
 #include <mlpack/core/kernels/kernel_traits.hpp>
 
 namespace mlpack {
-namespace kernel {
 
 /**
  * The Epanechnikov kernel, defined as
@@ -55,21 +54,21 @@ class EpanechnikovKernel
    * Evaluate the Epanechnikov kernel given that the distance between the two
    * input points is known.
    */
-  double Evaluate(const double distance) const;
+  inline double Evaluate(const double distance) const;
 
   /**
    * Evaluate the Gradient of Epanechnikov kernel
    * given that the distance between the two
    * input points is known.
    */
-  double Gradient(const double distance) const;
+  inline double Gradient(const double distance) const;
 
   /**
    * Evaluate the Gradient of Epanechnikov kernel
    * given that the squared distance between the two
    * input points is known.
    */
-  double GradientForSquaredDistance(const double distanceSquared) const;
+  inline double GradientForSquaredDistance(const double distanceSquared) const;
   /**
    * Obtains the convolution integral [integral of K(||x-a||) K(||b-x||) dx]
    * for the two vectors.
@@ -87,13 +86,13 @@ class EpanechnikovKernel
    *
    * @param dimension Dimension to calculate the normalizer for.
    */
-  double Normalizer(const size_t dimension);
+  inline double Normalizer(const size_t dimension);
 
   /**
    * Serialize the kernel.
    */
   template<typename Archive>
-  void serialize(Archive& ar, const unsigned int version);
+  void serialize(Archive& ar, const uint32_t version);
 
  private:
   //! Bandwidth of the kernel.
@@ -113,7 +112,6 @@ class KernelTraits<EpanechnikovKernel>
   static const bool UsesSquaredDistance = true;
 };
 
-} // namespace kernel
 } // namespace mlpack
 
 // Include implementation.
